﻿using System;
using System.IO;
using System.Linq;

namespace FindMissingPic
{
    class Program
    {
        static void Main(string[] args)
        {
            Crawl(new DirectoryInfo(args.Length == 0 ? "." : args[0]));
        }

        static void Crawl(DirectoryInfo folder)
        {
            foreach (var child in folder.GetDirectories())
                Crawl(child);

            if (HaveAudioFile(folder) && !HaveImageFile(folder))
                Console.WriteLine(folder.FullName);
        }

        private static bool HaveImageFile(DirectoryInfo folder)
        {
            return folder.GetFiles().Where(IsImageFile).Any();
        }

        private static bool HaveAudioFile(DirectoryInfo folder)
        {
            return folder.GetFiles().Where(IsAudioFile).Any();
        }

        private static bool IsAudioFile(FileInfo fileInfo)
        {
            return AudioExtension.Contains(fileInfo.Extension, StringComparer.InvariantCultureIgnoreCase);
        }

        private static bool IsImageFile(FileInfo fileInfo)
        {
            return ImageExtension.Contains(fileInfo.Extension, StringComparer.InvariantCultureIgnoreCase);
        }

        private static readonly string[] AudioExtension = new[] { ".wav", ".flac", ".mp3" };
        private static readonly string[] ImageExtension = new[] { ".jpg", ".jpeg", ".png" };
    }
}
